[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - list: list() -> new list list(sequence) -> new list initialized from sequence's items
    - polib._BaseFile: Common parent class for POFile and MOFile classes.
      - polib.POFile: Po (or Pot) file reader/writer.
      - polib.MOFile: Mo file reader/writer.
- polib._BaseEntry: Base class for POEntry or MOEntry objects.
  - polib.POEntry: Represents a po file entry.
  - polib.MOEntry: Represents a mo file entry.
- polib._MOFileParser: A class to parse binary mo files.
- polib._POFileParser: A finite state machine to parse efficiently and correctly po file format.